@@ -1,13 +1,13 @@
 package Data::Format::Pretty::Console;
 
-our $DATE = '2016-03-13'; # DATE
-our $VERSION = '0.37'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.38'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use experimental 'smartmatch';
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 use Scalar::Util qw(blessed);
 use Text::ANSITable;
@@ -485,7 +485,7 @@ Data::Format::Pretty::Console - Pretty-print data structure for console output
 
 =head1 VERSION
 
-This document describes version 0.37 of Data::Format::Pretty::Console (from Perl distribution Data-Format-Pretty-Console), released on 2016-03-13.
+This document describes version 0.38 of Data::Format::Pretty::Console (from Perl distribution Data-Format-Pretty-Console), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
@@ -701,7 +701,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Forma
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Format-Pretty-Console>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Format-Pretty-Console>.
 
 =head1 BUGS
 
@@ -723,7 +723,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011, 2010 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
